@@ -23,7 +23,7 @@ class ft_connector:
 			reply = requests.post(url,auth=(UID, SECRET),data={'scope': scope, 'grant_type':grant_type,'client_id':UID,'client_secret':SECRET})
 			reply.raise_for_status()
 		except requests.exceptions.HTTPError as err:
-				exit(print(self.RED + err))
+				exit(print(self.RED + str(err)))
 		token = json.loads(reply.text)
 		self.head = {'Authorization' : "Bearer {}".format(token['access_token'])}
 		self.url = 'https://api.intra.42.fr/v2'
