@@ -119,7 +119,7 @@ class update_properties:
 
 	def update_number(self, elem):
 		if elem['properties']['number'] != elem['value']:
-			elem['properties']['number'] = elem['number']
+			elem['properties']['number'] = elem['value']
 		else:
 			return None
 		return elem
@@ -152,5 +152,5 @@ class update_properties:
 			"created_by": self.update_created_by,
 			"created_time": self.update_created_time
 		}
-		ret = function[elem['type']](elem)
+		ret = function[elem['properties']['type']](elem)
 		return ret
